require 'test/unit'

# Select training if you want to renew golden files.
#TRAINING = true
TRAINING = false


# Test execution routine.
def runTest( test, cmdopts )
    rf = "result/#{test}.txt"
    gf = "golden/#{test}.txt"

    system( "export RUBYLIB=../lib; ../bin/crun #{cmdopts} > #{rf}" )

    if TRAINING
        # Populate golden files after inspection.
        system( "cp #{rf} #{gf}" )
    end

    assert( system( "diff #{rf} #{gf}" ), "FAILED: diff #{rf} #{gf}" )
end


# Tests.
class CrunTest < Test::Unit::TestCase

    def setup
        Dir.chdir( 'test' )
        FileUtils.mkdir_p "result"
    end

    def teardown
        Dir.chdir( '..' )
    end

    def test_basic()      runTest( "basic", "-f ../examples/greeting.c" ); end
    def test_conf()       runTest( "conf", "-f ../examples/greeting.c -c ../examples/crun_conf.rb" ); end
    def test_override()   runTest( "override", "-f ../examples/greeting.c -c ../examples/crun_conf.rb -o \"progopts:.-c 20\"" ); end
    def test_override2()  runTest( "override2", "-f ../examples/greeting.c -o \"progopts:.-c 13\"" ); end
    def test_override3()  runTest( "override3", "-f ../examples/greeting.c -o \"progopts:+-c 13\"" ); end
    def test_template()   runTest( "template", "-f ../examples/greeting.c -o \"progopts:+-c 13\" -t" ); end
    def test_autoheader() runTest( "autoheader", "-a -f ../examples/greeting_noheader.c" ); end

end
